@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -68,8 +68,6 @@ void *child(void *arg) {
 	/* Allows main thread to proceed with creation of other threads */
 	sem_post(poller_details.thread_init_sem);
 
-	free(arg);
-
 	if (is_debug_device(host_id)) {
 		SPINE_LOG(("DEBUG: In Poller, About to Start Polling of Device for Device ID %i", host_id));
 	} else {
@@ -90,6 +88,7 @@ void *child(void *arg) {
 
 	thread_mutex_lock(LOCK_PEND);
 	pending_threads--;
+	poller_details.complete = TRUE;
 
 	SPINE_LOG_MEDIUM(("POLLER: Active Threads is %i, Pending is %i", set.threads - a_threads_value, pending_threads));
 	thread_mutex_unlock(LOCK_PEND);
@@ -754,7 +753,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 
 							break;
 						case POLLER_ACTION_SCRIPT: /* script (popen) */
-							poll_result = trim(exec_poll(host, reindex->arg1));
+							poll_result = trim(exec_poll(host, reindex->arg1, reindex->data_query_id, "DQ"));
 							if (is_debug_device(host->id)) {
 								SPINE_LOG(("Device[%i] HT[%i] DQ[%i] RECACHE CMD: %s, output: %s", host->id, host_thread, reindex->data_query_id, reindex->arg1, poll_result));
 							} else {
@@ -792,7 +791,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 							}
 							poll_result[0] = '\0';
 
-							snprintf(poll_result, BUFSIZE, "%d", char_count(exec_poll(host, reindex->arg1), '\n'));
+							snprintf(poll_result, BUFSIZE, "%d", char_count(exec_poll(host, reindex->arg1, reindex->data_query_id, "DQ"), '\n'));
 							if (is_debug_device(host->id)) {
 								SPINE_LOG(("Device[%i] HT[%i] DQ[%i] RECACHE CMD COUNT: %s, output: %s", host->id, host_thread, reindex->data_query_id, reindex->arg1, poll_result));
 							} else {
@@ -820,7 +819,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 						}
 
 						if (!reindex_err) {
-							if (!(query3 = (char *)malloc(BUFSIZE))) {
+							if (!(query3 = (char *)malloc(LRG_BUFSIZE))) {
 								die("ERROR: Fatal malloc error: poller.c reindex insert!");
 							}
 							query3[0] = '\0';
@@ -843,7 +842,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 								}
 
 								if (host_thread == 1) {
-									snprintf(query3, BUFSIZE, "REPLACE INTO poller_command (poller_id, time, action,command) values (%i, NOW(), %i, '%i:%i')", set.poller_id, POLLER_COMMAND_REINDEX, host->id, reindex->data_query_id);
+									snprintf(query3, LRG_BUFSIZE, "REPLACE INTO poller_command (poller_id, time, action,command) values (%i, NOW(), %i, '%i:%i')", set.poller_id, POLLER_COMMAND_REINDEX, host->id, reindex->data_query_id);
 
 									if (set.mode == REMOTE_ONLINE) {
 										db_insert(&mysqlr, REMOTE, query3);
@@ -865,7 +864,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 								}
 
 								if (host_thread == 1) {
-									snprintf(query3, BUFSIZE, "REPLACE INTO poller_command (poller_id, time, action, command) values (%i, NOW(), %i, '%i:%i')", set.poller_id, POLLER_COMMAND_REINDEX, host->id, reindex->data_query_id);
+									snprintf(query3, LRG_BUFSIZE, "REPLACE INTO poller_command (poller_id, time, action, command) values (%i, NOW(), %i, '%i:%i')", set.poller_id, POLLER_COMMAND_REINDEX, host->id, reindex->data_query_id);
 
 									if (set.mode == REMOTE_ONLINE) {
 										db_insert(&mysqlr, REMOTE, query3);
@@ -889,7 +888,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 									}
 
 									if (host_thread == 1) {
-										snprintf(query3, BUFSIZE, "REPLACE INTO poller_command (poller_id, time, action, command) values (%i, NOW(), %i, '%i:%i')", set.poller_id, POLLER_COMMAND_REINDEX, host->id, reindex->data_query_id);
+										snprintf(query3, LRG_BUFSIZE, "REPLACE INTO poller_command (poller_id, time, action, command) values (%i, NOW(), %i, '%i:%i')", set.poller_id, POLLER_COMMAND_REINDEX, host->id, reindex->data_query_id);
 
 										if (set.mode == REMOTE_ONLINE) {
 											db_insert(&mysqlr, REMOTE, query3);
@@ -910,7 +909,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 								if (host_thread == 1) {
 									db_escape(&mysql, temp_poll_result, sizeof(temp_poll_result), poll_result);
 									db_escape(&mysql, temp_arg1, sizeof(temp_arg1), reindex->arg1);
-									snprintf(query3, BUFSIZE, "UPDATE poller_reindex SET assert_value='%s' WHERE host_id='%i' AND data_query_id='%i' AND arg1='%s'", temp_poll_result, host_id, reindex->data_query_id, temp_arg1);
+									snprintf(query3, LRG_BUFSIZE, "UPDATE poller_reindex SET assert_value='%s' WHERE host_id='%i' AND data_query_id='%i' AND arg1='%s'", temp_poll_result, host_id, reindex->data_query_id, temp_arg1);
 									db_insert(&mysql, LOCAL, query3);
 								}
 
@@ -1333,7 +1332,7 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 
 				break;
 			case POLLER_ACTION_SCRIPT: /* execute script file */
-				poll_result = exec_poll(host, poller_items[i].arg1);
+				poll_result = exec_poll(host, poller_items[i].arg1, poller_items[i].local_data_id, "DS");
 
 				/* process the result */
 				if (IS_UNDEFINED(poll_result)) {
@@ -1686,9 +1685,9 @@ void poll_host(int host_id, int host_thread, int last_host_thread, int host_data
 	/* record the polling time for the device */
 	poll_time = get_time_as_double() - poll_time;
 	if (is_debug_device(host_id)) {
-		SPINE_LOG(("Device[%i] HT[%i] Total Time: %5.2g Seconds", host_id, host_thread, poll_time));
+		SPINE_LOG(("Device[%i] HT[%i] Total Time: %0.2g Seconds", host_id, host_thread, poll_time));
 	} else {
-		SPINE_LOG_MEDIUM(("Device[%i] HT[%i] Total Time: %5.2g Seconds", host_id, host_thread, poll_time));
+		SPINE_LOG_MEDIUM(("Device[%i] HT[%i] Total Time: %0.2g Seconds", host_id, host_thread, poll_time));
 	}
 
 	/* record the total time for the host */
@@ -1769,56 +1768,79 @@ int is_multipart_output(char *result) {
 void get_system_information(host_t *host, MYSQL *mysql, int system)  {
 	char *poll_result;
 
+	SPINE_LOG_MEDIUM(("NOTE: Device[%d] Checking for System Information Update", host->id));
+
 	if (set.mibs || system) {
 		if (is_debug_device(host->id)) {
-			SPINE_LOG(("Updating Full System Information Table"));
+			SPINE_LOG(("NOTE: Device[%d] Updating Full System Information Table", host->id));
 		} else {
-			SPINE_LOG_MEDIUM(("Updating Full System Information Table"));
+			SPINE_LOG_MEDIUM(("NOTE: Device[%d] Updating Full System Information Table", host->id));
 		}
 
+		SPINE_LOG_DEVDBG(("DEVDBG: Device[%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.1.0');", host->id));
 		poll_result = snmp_get(host, ".1.3.6.1.2.1.1.1.0");
+		SPINE_LOG_DEVDBG(("DEVDBG: Device[%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.1.0'); [complete]", host->id));
+
 		if (poll_result) {
 			db_escape(mysql, host->snmp_sysDescr, sizeof(host->snmp_sysDescr), poll_result);
+			free(poll_result);
 		}
-		free(poll_result);
 
+		SPINE_LOG_DEVDBG(("DEVDBG: Device[%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.2.0');", host->id));
 		poll_result = snmp_get(host, ".1.3.6.1.2.1.1.2.0");
+		SPINE_LOG_DEVDBG(("DEVDBG: Device[%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.2.0'); [complete]", host->id));
+
 		if (poll_result) {
 			db_escape(mysql, host->snmp_sysObjectID, sizeof(host->snmp_sysObjectID), poll_result);
 			free(poll_result);
 		}
 
+		SPINE_LOG_DEVDBG(("DEVDBG: Device[%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.3.0');", host->id));
 		poll_result = snmp_get(host, ".1.3.6.1.2.1.1.3.0");
+		SPINE_LOG_DEVDBG(("DEVDGB: Device[%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.3.0'); [complete]", host->id));
+
 		if (poll_result) {
 			host->snmp_sysUpTimeInstance = atoi(poll_result);
 			free(poll_result);
 		}
 
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.4.0');", host->id));
 		poll_result = snmp_get(host, ".1.3.6.1.2.1.1.4.0");
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.4.0'); [complete]", host->id));
+
 		if (poll_result) {
 			db_escape(mysql, host->snmp_sysContact, sizeof(host->snmp_sysContact), poll_result);
 			free(poll_result);
 		}
 
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.5.0');", host->id));
 		poll_result = snmp_get(host, ".1.3.6.1.2.1.1.5.0");
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.5.0'); [complete]", host->id));
+
 		if (poll_result) {
 			db_escape(mysql, host->snmp_sysName, sizeof(host->snmp_sysName), poll_result);
 			free(poll_result);
 		}
 
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.6.0');", host->id));
 		poll_result = snmp_get(host, ".1.3.6.1.2.1.1.6.0");
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.6.0'); [complete]", host->id));
+
 		if (poll_result) {
 			db_escape(mysql, host->snmp_sysLocation, sizeof(host->snmp_sysLocation), poll_result);
 			free(poll_result);
 		}
 	} else {
 		if (is_debug_device(host->id)) {
-			SPINE_LOG(("Updating Short System Information Table"));
+			SPINE_LOG(("NOTE: Device[%d] Updating Short System Information Table", host->id));
 		} else {
-			SPINE_LOG_MEDIUM(("Updating Short System Information Table"));
+			SPINE_LOG_MEDIUM(("NOTE: Device[%d] Updating Short System Information Table", host->id));
 		}
 
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.3.0');", host->id));
 		poll_result = snmp_get(host, ".1.3.6.1.2.1.1.3.0");
+		SPINE_LOG_DEVDBG(("DEVDBG: Device [%d] poll_result = snmp_get(host, '.1.3.6.1.2.1.1.3.0'); [complete]", host->id));
+
 		if (poll_result) {
 			host->snmp_sysUpTimeInstance = atoi(poll_result);
 			free(poll_result);
@@ -1853,10 +1875,11 @@ int validate_result(char *result) {
 	return FALSE;
 }
 
-/*! \fn char *exec_poll(host_t *current_host, char *command)
+/*! \fn char *exec_poll(host_t *current_host, char *command, int id, char *type)
  *  \brief polls a host using a script
  *  \param current_host a pointer to the current host structure
  *  \param command the command to be executed
+ *  \param id either the local_data_id or the data_query_id
  *
  *	This function will poll a specific host using the script pointed to by
  *  the command variable.
@@ -1864,7 +1887,7 @@ int validate_result(char *result) {
  *  \return a pointer to a character buffer containing the result.
  *
  */
-char *exec_poll(host_t *current_host, char *command) {
+char *exec_poll(host_t *current_host, char *command, int id, char *type) {
 	extern sem_t active_scripts;
 	int cmd_fd;
 	int pid;
@@ -1993,7 +2016,11 @@ char *exec_poll(host_t *current_host, char *command) {
 			if (bytes_read > 0) {
 				result_string[bytes_read] = '\0';
 			} else {
-				SPINE_LOG(("Device[%i] ERROR: Empty result [%s]: '%s'", current_host->id, current_host->hostname, command));
+				if (STRIMATCH(type,"DS")) {
+					SPINE_LOG(("Device[%i] DS[%i] ERROR: Empty result [%s]: '%s'", current_host->id, id, current_host->hostname, command));
+				} else {
+					SPINE_LOG(("Device[%i] DQ[%i] ERROR: Empty result [%s]: '%s'", current_host->id, id, current_host->hostname, command));
+				}
 				SET_UNDEFINED(result_string);
 			}
 		}
