@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -115,9 +115,9 @@ void snmp_spine_close(void) {
  *
  */
 void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_community,
-					char *snmp_username, char *snmp_password, char *snmp_auth_protocol,
-					char *snmp_priv_passphrase, char *snmp_priv_protocol,
-					char *snmp_context, char *snmp_engine_id, int snmp_port, int snmp_timeout) {
+	char *snmp_username, char *snmp_password, char *snmp_auth_protocol,
+	char *snmp_priv_passphrase, char *snmp_priv_protocol,
+	char *snmp_context, char *snmp_engine_id, int snmp_port, int snmp_timeout) {
 
 	void   *sessp = NULL;
 	struct snmp_session session;
@@ -189,6 +189,8 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 	session.remote_port = snmp_port;
 	session.timeout     = (snmp_timeout * 1000); /* net-snmp likes microseconds */
 
+	SPINE_LOG_MEDIUM(("Device[%i] INFO: SNMP Device '%s' has timeout %ld (%d), retries %d", host_id, hostname, session.timeout, snmp_timeout, session.retries));
+
 	if ((snmp_version == 2) || (snmp_version == 1)) {
 		session.community     = (unsigned char*) snmp_community;
 		session.community_len = strlen(snmp_community);
@@ -328,6 +330,11 @@ char *snmp_get(host_t *current_host, char *snmp_oid) {
 	char   *result_string;
 	char   temp_result[RESULTS_BUFFER];
 
+	if (current_host->ignore_host) {
+		SPINE_LOG_HIGH(("WARNING: Skipped oid '%s' for Device[%d] as host ignore flag is active", snmp_oid, current_host->id));
+		return NULL;
+	}
+
 	if (!(result_string = (char *) malloc(RESULTS_BUFFER))) {
 		die("ERROR: Fatal malloc error: snmp.c snmp_get!");
 	}
@@ -337,18 +344,28 @@ char *snmp_get(host_t *current_host, char *snmp_oid) {
 
 	if (current_host->snmp_session != NULL) {
 		anOID_len = MAX_OID_LEN;
-		pdu       = snmp_pdu_create(SNMP_MSG_GET);
 
+		SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_pdu_create(%s)", current_host->id, snmp_oid));
+		pdu = snmp_pdu_create(SNMP_MSG_GET);
+		SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_pdu_create(%s) [complete]", current_host->id, snmp_oid));
+
+		SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_parse_oid(%s)", current_host->id, snmp_oid));
 		if (!snmp_parse_oid(snmp_oid, anOID, &anOID_len)) {
+			SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_parse_oid(%s) [complete]", current_host->id, snmp_oid));
 			SPINE_LOG(("Device[%i] ERROR: SNMP Get Problems parsing SNMP OID %s", current_host->id, snmp_oid));
 			SET_UNDEFINED(result_string);
 			return result_string;
 		} else {
+			SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_parse_oid(%s) [complete]", current_host->id, snmp_oid));
+			SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_add_null_var(%s)", current_host->id, snmp_oid));
 			snmp_add_null_var(pdu, anOID, anOID_len);
+			SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_add_null_var(%s) [complete]", current_host->id, snmp_oid));
 		}
 
 		/* poll host */
+		SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_sess_sync_response(%s)", current_host->id, snmp_oid));
 		status = snmp_sess_synch_response(current_host->snmp_session, pdu, &response);
+		SPINE_LOG_DEVDBG(("Device[%i] WARNING: snmp_sess_sync_response(%s) [complete]", current_host->id, snmp_oid));
 
 		/* add status to host structure */
 		current_host->snmp_status = status;
@@ -367,8 +384,12 @@ char *snmp_get(host_t *current_host, char *snmp_oid) {
 					snprint_value(temp_result, RESULTS_BUFFER, vars->name, vars->name_length, vars);
 
 					snprint_asciistring(result_string, RESULTS_BUFFER, temp_result, strlen(temp_result));
+				} else {
+					SPINE_LOG_HIGH(("ERROR: Failed to get oid '%s' for Device[%d]",  snmp_oid, current_host->id));
 				}
 			}
+		} else {
+			SPINE_LOG_HIGH(("ERROR: Failed to get oid '%s' for Device[%d]",  snmp_oid, current_host->id));
 		}
 
 		if (response) {
