@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -207,6 +207,7 @@ int main(int argc, char *argv[]) {
 	#endif /* HAVE_LCAP */
 
 	pthread_t* threads = NULL;
+	poller_thread_t** details = NULL;
 	poller_thread_t* poller_details = NULL;
 	pthread_attr_t attr;
 
@@ -224,6 +225,9 @@ int main(int argc, char *argv[]) {
 	int total_items   = 0;
 	int change_host   = TRUE;
 	int current_thread;
+	int threads_final = 0;
+	int threads_missing = -1;
+	int threads_count;
 
 	UNUSED_PARAMETER(argc);		/* we operate strictly with argv */
 
@@ -315,8 +319,7 @@ int main(int argc, char *argv[]) {
 
 		if (opt) *opt++ = '\0';
 
-		if (STRMATCH(arg, "-f") ||
-			STRMATCH(arg, "--first")) {
+		if (STRMATCH(arg, "-f") || STRMATCH(arg, "--first")) {
 			if (HOSTID_DEFINED(set.start_host_id)) {
 				die("ERROR: %s can only be used once", arg);
 			}
@@ -328,8 +331,7 @@ int main(int argc, char *argv[]) {
 			}
 		}
 
-		else if (STRMATCH(arg, "-l") ||
-				 STRIMATCH(arg, "--last")) {
+		else if (STRMATCH(arg, "-l") || STRIMATCH(arg, "--last")) {
 			if (HOSTID_DEFINED(set.end_host_id)) {
 				die("ERROR: %s can only be used once", arg);
 			}
@@ -341,38 +343,27 @@ int main(int argc, char *argv[]) {
 			}
 		}
 
-		else if (STRMATCH(arg, "-p") ||
-				 STRIMATCH(arg, "--poller")) {
+		else if (STRMATCH(arg, "-p") || STRIMATCH(arg, "--poller")) {
 			set.poller_id = atoi(getarg(opt, &argv));
 		}
 
-		else if (STRMATCH(arg, "-N") ||
-				 STRIMATCH(arg, "--mode")) {
-
+		else if (STRMATCH(arg, "-N") || STRIMATCH(arg, "--mode")) {
 			if (STRIMATCH(getarg(opt, &argv), "online")) {
 				set.mode = REMOTE_ONLINE;
-			}
-
-			else if (STRIMATCH(getarg(opt, &argv), "offline")) {
+			} else if (STRIMATCH(getarg(opt, &argv), "offline")) {
 				set.mode = REMOTE_OFFLINE;
-			}
-
-			else if (STRIMATCH(getarg(opt, &argv), "recovery")) {
+			} else if (STRIMATCH(getarg(opt, &argv), "recovery")) {
 				set.mode = REMOTE_RECOVERY;
-			}
-
-			else {
+			} else {
 				die("ERROR: invalid polling mode '%s' specified", opt);
 			}
 		}
 
-		else if (STRMATCH(arg, "-H") ||
-				 STRIMATCH(arg, "--hostlist")) {
+		else if (STRMATCH(arg, "-H") || STRIMATCH(arg, "--hostlist")) {
 			snprintf(set.host_id_list, BIG_BUFSIZE, "%s", getarg(opt, &argv));
 		}
 
-		else if (STRMATCH(arg, "-M") ||
-				 STRMATCH(arg, "--mibs")) {
+		else if (STRMATCH(arg, "-M") || STRMATCH(arg, "--mibs")) {
 			set.mibs = 1;
 		}
 
@@ -388,10 +379,9 @@ int main(int argc, char *argv[]) {
 			exit(EXIT_SUCCESS);
 		}
 
-		else if (STRMATCH(arg, "-O") ||
-				 STRIMATCH(arg, "--option")) {
-			char	*setting = getarg(opt, &argv);
-			char	*value   = strchr(setting, ':');
+		else if (STRMATCH(arg, "-O") || STRIMATCH(arg, "--option")) {
+			char *setting = getarg(opt, &argv);
+			char *value   = strchr(setting, ':');
 
 			if (*value) {
 				*value++ = '\0';
@@ -402,34 +392,27 @@ int main(int argc, char *argv[]) {
 			set_option(setting, value);
 		}
 
-		else if (STRMATCH(arg, "-R") ||
-				 STRMATCH(arg, "--readonly") ||
-				 STRMATCH(arg, "--read-only")) {
+		else if (STRMATCH(arg, "-R") || STRMATCH(arg, "--readonly") || STRMATCH(arg, "--read-only")) {
 			set.SQL_readonly = TRUE;
 		}
 
-		else if (STRMATCH(arg, "-C") ||
-				 STRMATCH(arg, "--conf")) {
+		else if (STRMATCH(arg, "-C") || STRMATCH(arg, "--conf")) {
 			conf_file = strdup(getarg(opt, &argv));
 		}
 
-		else if (STRMATCH(arg, "-S") ||
-				 STRMATCH(arg, "--stdout")) {
+		else if (STRMATCH(arg, "-S") || STRMATCH(arg, "--stdout")) {
 			set_option("log_destination", "STDOUT");
 		}
 
-		else if (STRMATCH(arg, "-L") ||
-				 STRMATCH(arg, "--log")) {
+		else if (STRMATCH(arg, "-L") || STRMATCH(arg, "--log")) {
 			set_option("log_destination", getarg(opt, &argv));
 		}
 
-		else if (STRMATCH(arg, "-V") ||
-				 STRMATCH(arg, "--verbosity")) {
+		else if (STRMATCH(arg, "-V") || STRMATCH(arg, "--verbosity")) {
 			set_option("log_verbosity", getarg(opt, &argv));
 		}
 
-		else if (STRMATCH(arg, "--snmponly") ||
-				 STRMATCH(arg, "--snmp-only")) {
+		else if (STRMATCH(arg, "--snmponly") || STRMATCH(arg, "--snmp-only")) {
 			set.snmponly = TRUE;
 		}
 
@@ -480,12 +463,12 @@ int main(int argc, char *argv[]) {
 			valid_conf_file = TRUE;
 		}
 	} else {
-		if (!(conf_file = calloc(CONFIG_PATHS, BUFSIZE))) {
+		if (!(conf_file = calloc(CONFIG_PATHS, DBL_BUFSIZE))) {
 			die("ERROR: Fatal malloc error: spine.c conf_file!");
 		}
 
 		for (i=0; i<CONFIG_PATHS; i++) {
-			snprintf(conf_file, BUFSIZE, "%s%s", config_paths[i], DEFAULT_CONF_FILE);
+			snprintf(conf_file, DBL_BUFSIZE, "%s%s", config_paths[i], DEFAULT_CONF_FILE);
 
 			if (read_spine_config(conf_file) >= 0) {
 				valid_conf_file = TRUE;
@@ -493,7 +476,7 @@ int main(int argc, char *argv[]) {
 			}
 
 			if (i == CONFIG_PATHS-1) {
-				snprintf(conf_file, BUFSIZE, "%s%s", config_paths[0], DEFAULT_CONF_FILE);
+				snprintf(conf_file, DBL_BUFSIZE, "%s%s", config_paths[0], DEFAULT_CONF_FILE);
 			}
 		}
 	}
@@ -622,16 +605,21 @@ int main(int argc, char *argv[]) {
 	qp += sprintf(qp, " ORDER BY polling_time DESC");
 
 	result = db_query(&mysql, LOCAL, querybuf);
-	if (set.poller_id == 0) {
-		num_rows = mysql_num_rows(result) + 1; /* add 1 for host = 0 */
+
+	if (set.poller_id == 1) {
+		num_rows = mysql_num_rows(result) + 1; /* pollerid 1 takes care of not host based data sources */
 	} else {
-		num_rows = mysql_num_rows(result); /* pollerid 0 takes care of not host based data sources */
+		num_rows = mysql_num_rows(result);
 	}
 
 	if (!(threads = (pthread_t *)malloc(num_rows * sizeof(pthread_t)))) {
 		die("ERROR: Fatal malloc error: spine.c threads!");
 	}
 
+	if (!(details = (poller_thread_t **)malloc(num_rows * sizeof(poller_thread_t*)))) {
+		die("ERROR: Fatal malloc error: spine.c details!");
+	}
+
 	if (!(ids = (int *)malloc(num_rows * sizeof(int)))) {
 		die("ERROR: Fatal malloc error: spine.c host id's!");
 	}
@@ -674,7 +662,7 @@ int main(int argc, char *argv[]) {
 	current_thread   = 0;
 
 	/* poller 0 always polls host 0 */
-	if (set.poller_id == 0) {
+	if (set.poller_id == 1) {
 		host_id     = 0;
 		change_host = FALSE;
 	} else {
@@ -688,6 +676,10 @@ int main(int argc, char *argv[]) {
 			host_id         = atoi(mysql_row[0]);
 			device_threads  = atoi(mysql_row[1]);
 			current_thread  = 1;
+
+			if (device_threads < 1) {
+				device_threads = 1;
+			}
 		} else {
 			current_thread++;
 		}
@@ -717,12 +709,15 @@ int main(int argc, char *argv[]) {
 				db_free_result(tresult);
 
 				if (host_time) free(host_time);
+
 				host_time = get_host_poll_time();
 				host_time_double = get_time_as_double();
 			}
 		} else {
-			itemsPT   = 0;
+			itemsPT = 0;
+
 			if (host_time) free(host_time);
+
 			host_time = get_host_poll_time();
 			host_time_double = get_time_as_double();
 		}
@@ -739,6 +734,9 @@ int main(int argc, char *argv[]) {
 		poller_details->host_time        = host_time;
 		poller_details->host_time_double = host_time_double;
 		poller_details->thread_init_sem  = &thread_init_sem;
+		poller_details->complete         = FALSE;
+
+		details[device_counter]          = poller_details;
 
 		retry1:
 
@@ -776,6 +774,15 @@ int main(int argc, char *argv[]) {
 				thread_mutex_unlock(LOCK_PEND);
 				sem_post(&thread_init_sem);
 
+				SPINE_LOG_DEVDBG(("INFO: DTS: device = %d, host_id = %d, host_thread = %d,"
+					" last_host_thread = %d, host_data_ids = %d, complete = %d",
+					device_counter-1,
+					poller_details->host_id,
+					poller_details->host_thread,
+					poller_details->last_host_thread,
+					poller_details->host_data_ids,
+					poller_details->complete));
+
 				break;
 			case EAGAIN:
 				SPINE_LOG(("ERROR: The System Lacked the Resources to Create a Thread"));
@@ -791,8 +798,9 @@ int main(int argc, char *argv[]) {
 		}
 
 		/* Restore thread initialization semaphore if thread creation failed */
-		if (thread_status)
+		if (thread_status) {
 			sem_post(&thread_init_sem);
+		}
 	}
 
 	/* wait for all threads to 'complete'
@@ -806,17 +814,53 @@ int main(int argc, char *argv[]) {
 		if (pending_threads == 0) {
 			break;
 		} else if (cur_time - begin_time > set.poller_interval) {
-			SPINE_LOG(("ERROR: Spine Timed Out While Waiting for Threads to End"));
+			SPINE_LOG(("ERROR: Spine Timed Out While Waiting for %d Threads to End", pending_threads));
 			break;
 		}
 
 		thread_mutex_unlock(LOCK_PEND);
 
-		sleep(1);
+		usleep(100000);
 	}
 
 	sem_getvalue(&active_threads, &a_threads_value);
-	SPINE_LOG_MEDIUM(("SPINE: The Final Value of Threads is %i", set.threads - a_threads_value));
+
+	threads_final = set.threads - a_threads_value;
+
+	if (threads_final) {
+		SPINE_LOG_HIGH(("SPINE: The final count of Threads is %i", threads_final));
+
+		for (threads_count = 0; threads_count < num_rows; threads_count++) {
+			poller_thread_t* det = details[threads_count];
+
+			if (threads_missing == -1 && det == NULL) {
+				threads_missing = threads_count;
+			}
+
+			if (det != NULL) { // && !det->complete) {
+				SPINE_LOG_HIGH(("INFO: Thread %scomplete for Device[%d] and %d to %d sources",
+					det->complete?"":"in",
+					det->host_id,
+					det->host_data_ids * (det->host_thread - 1),
+					det->host_data_ids * (det->host_thread)));
+
+				SPINE_LOG_DEVDBG(("INFO: DTF: device = %d, host_id = %d, host_thread = %d,"
+					" last_host_thread = %d, host_data_ids = %d, complete = %d",
+					threads_count,
+					det->host_id,
+					det->host_thread,
+					det->last_host_thread,
+					det->host_data_ids,
+					det->complete));
+			}
+		}
+
+		if (threads_missing > -1) {
+			SPINE_LOG_HIGH(("ERROR: There were %d threads which did not run", num_rows - threads_missing));
+		}
+	} else {
+		SPINE_LOG_MEDIUM(("SPINE: The Final Value of Threads is %i", threads_final));
+	}
 
 	/* tell Spine that it is now parent */
 	set.parent_fork = SPINE_PARENT;
@@ -854,6 +898,13 @@ int main(int argc, char *argv[]) {
 	SPINE_LOG_DEBUG(("DEBUG: PHP Script Server Pipes Closed"));
 
 	/* free malloc'd variables */
+	for (i = 0; i < num_rows; i++) {
+		if (details[i] != NULL) {
+			free(details[i]);
+		}
+	}
+
+	free(details);
 	free(threads);
 	free(ids);
 	free(conf_file);
@@ -943,7 +994,7 @@ static void display_help(int only_version) {
 		0 /* ENDMARKER */
 	};
 
-	printf("SPINE %s  Copyright 2004-2017 by The Cacti Group\n", VERSION);
+	printf("SPINE %s  Copyright 2004-2019 by The Cacti Group\n", VERSION);
 
 	if (only_version == FALSE) {
 		printf("\n");
