@@ -1,7 +1,7 @@
 /*
  ex: set tabstop=4 shiftwidth=4 autoindent:
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU Lesser General Public              |
@@ -187,6 +187,7 @@ void db_connect(int type, MYSQL *mysql) {
 	int    options_error;
 	int    success;
 	int    error;
+	bool   reconnect;
 	MYSQL  *connect_error;
 	char   *hostname;
 	char   *socket = NULL;
@@ -229,7 +230,7 @@ void db_connect(int type, MYSQL *mysql) {
 	timeout = 5;
 	rtimeout = 10;
 	wtimeout = 20;
-	my_bool reconnect = 1;
+	reconnect = 1;
 
 	mysql_init(mysql);
 
@@ -326,7 +327,9 @@ void db_connect(int type, MYSQL *mysql) {
  *
  */
 void db_disconnect(MYSQL *mysql) {
-	mysql_close(mysql);
+	if (mysql != NULL) {
+		mysql_close(mysql);
+	}
 }
 
 /*! \fn int append_hostrange(char *obuf, const char *colname, const config_t *set)
